==> heap-sort-9.0.0.tgz: package/README.md <==
[js-heapsort](http://comparison-sorting.github.io/heap-sort)
==

Heapsort algorithms for JavaScript. Parents are
[js-sorting](https://github.com/make-github-pseudonymous-again/js-sorting)
and
[@heap-data-structure](https://github.com/heap-data-structure/about).

```js
let sort = heapsort.dary( 2 ) ;
```

[![License](https://img.shields.io/github/license/comparison-sorting/heap-sort.svg)](https://raw.githubusercontent.com/comparison-sorting/heap-sort/main/LICENSE)
[![Version](https://img.shields.io/npm/v/@comparison-sorting/heap-sort.svg)](https://www.npmjs.org/package/@comparison-sorting/heap-sort)
[![Build](https://img.shields.io/travis/comparison-sorting/heap-sort/main.svg)](https://travis-ci.org/comparison-sorting/heap-sort/branches)
[![Dependencies](https://img.shields.io/david/comparison-sorting/heap-sort.svg)](https://david-dm.org/comparison-sorting/heap-sort)
[![Dev dependencies](https://img.shields.io/david/dev/comparison-sorting/heap-sort.svg)](https://david-dm.org/comparison-sorting/heap-sort?type=dev)
[![GitHub issues](https://img.shields.io/github/issues/comparison-sorting/heap-sort.svg)](https://github.com/comparison-sorting/heap-sort/issues)
[![Downloads](https://img.shields.io/npm/dm/@comparison-sorting/heap-sort.svg)](https://www.npmjs.org/package/@comparison-sorting/heap-sort)

[![Code issues](https://img.shields.io/codeclimate/issues/comparison-sorting/heap-sort.svg)](https://codeclimate.com/github/comparison-sorting/heap-sort/issues)
[![Code maintainability](https://img.shields.io/codeclimate/maintainability/comparison-sorting/heap-sort.svg)](https://codeclimate.com/github/comparison-sorting/heap-sort/trends/churn)
[![Code coverage (cov)](https://img.shields.io/codecov/c/gh/comparison-sorting/heap-sort/main.svg)](https://codecov.io/gh/comparison-sorting/heap-sort)
[![Code technical debt](https://img.shields.io/codeclimate/tech-debt/comparison-sorting/heap-sort.svg)](https://codeclimate.com/github/comparison-sorting/heap-sort/trends/technical_debt)
[![Documentation](http://comparison-sorting.github.io/heap-sort/badge.svg)](http://comparison-sorting.github.io/heap-sort/source.html)
[![Package size](https://img.shields.io/bundlephobia/minzip/@comparison-sorting/heap-sort)](https://bundlephobia.com/result?p=@comparison-sorting/heap-sort)

## Reference

  - http://sorting.at

==> heap-sort-10.0.0.tgz: package/README.md <==
[js-heapsort](https://comparison-sorting.github.io/heap-sort)
==

Heapsort algorithms for JavaScript. Parents are
[js-sorting](https://github.com/make-github-pseudonymous-again/js-sorting)
and
[@heap-data-structure](https://github.com/heap-data-structure/about).

```js
let sort = heapsort.dary( 2 ) ;
```

[![License](https://img.shields.io/github/license/comparison-sorting/heap-sort.svg)](https://raw.githubusercontent.com/comparison-sorting/heap-sort/main/LICENSE)
[![Version](https://img.shields.io/npm/v/@comparison-sorting/heap-sort.svg)](https://www.npmjs.org/package/@comparison-sorting/heap-sort)
[![Tests](https://img.shields.io/github/workflow/status/comparison-sorting/heap-sort/ci:test?event=push&label=tests)](https://github.com/comparison-sorting/heap-sort/actions/workflows/ci:test.yml?query=branch:main)
[![Dependencies](https://img.shields.io/librariesio/github/comparison-sorting/heap-sort.svg)](https://github.com/comparison-sorting/heap-sort/network/dependencies)
[![GitHub issues](https://img.shields.io/github/issues/comparison-sorting/heap-sort.svg)](https://github.com/comparison-sorting/heap-sort/issues)
[![Downloads](https://img.shields.io/npm/dm/@comparison-sorting/heap-sort.svg)](https://www.npmjs.org/package/@comparison-sorting/heap-sort)

[![Code issues](https://img.shields.io/codeclimate/issues/comparison-sorting/heap-sort.svg)](https://codeclimate.com/github/comparison-sorting/heap-sort/issues)
[![Code maintainability](https://img.shields.io/codeclimate/maintainability/comparison-sorting/heap-sort.svg)](https://codeclimate.com/github/comparison-sorting/heap-sort/trends/churn)
[![Code coverage (cov)](https://img.shields.io/codecov/c/gh/comparison-sorting/heap-sort/main.svg)](https://codecov.io/gh/comparison-sorting/heap-sort)
[![Code technical debt](https://img.shields.io/codeclimate/tech-debt/comparison-sorting/heap-sort.svg)](https://codeclimate.com/github/comparison-sorting/heap-sort/trends/technical_debt)
[![Documentation](https://comparison-sorting.github.io/heap-sort/badge.svg)](https://comparison-sorting.github.io/heap-sort/source.html)
[![Package size](https://img.shields.io/bundlephobia/minzip/@comparison-sorting/heap-sort)](https://bundlephobia.com/result?p=@comparison-sorting/heap-sort)

## Reference

  - http://sorting.at
